#!/usr/bin/env python
import matplotlib.pyplot as pyplot
import mcidasx
import netCDF4
import numpy
import os
import sys

mcidas_dir = os.path.expanduser('~mcidas')

path = [os.environ['PATH'],
        os.path.join(mcidas_dir, 'bin')]

mcpath = [os.path.dirname(__file__),
          os.path.join(os.environ['HOME'], 'mcidas/data'),
          os.path.join(mcidas_dir, 'data')]

os.environ['PATH'] = ':'.join(path)
os.environ['MCPATH'] = ':'.join(mcpath)

mcenv = mcidasx.mcidas.mcenv()
mcenv.logon('DEMO 1234')

result1 = mcenv.dataloc('ADD MUG2015 arcserv2.ssec.wisc.edu')
if result1.retcode != 0:
    sys.exit(result1.stdout)

mcenv.dsserve('ADD N/A NCDF 1 9999 TYPE=IMAGE')

msg_ndvi_bands = [1, 2]

imgcopy_string = 'MUG2015/NDVI N/A.{band} SIZE=SAME BAND={band} MAG=-8 DAY=2011/08/31 TIME=12 UNIT=REFL'
for band in msg_ndvi_bands:
    imgcopy_result = mcenv.imgcopy(imgcopy_string.format(band=band))
    print imgcopy_result.stdout

try:
    # open the NetCDF files
    redBand = netCDF4.Dataset('A0001.nc', 'r')
    nirBand = netCDF4.Dataset('A0002.nc', 'r')

    # pull out the band data
    redData = numpy.array(redBand.variables['data'][0])
    nirData = numpy.array(nirBand.variables['data'][0])

    check = numpy.logical_and(redData != 0, nirData != 0)
    ndvi = numpy.where(check, (nirData - redData) / (nirData + redData), 0) 

    pyplot.imshow(ndvi, cmap=pyplot.get_cmap('PRGn'), vmin=-1, vmax=1)
    pyplot.savefig('ndvi.png')
    pyplot.show()

except:
    sys.exit('An error occurred.')
